@@ -1,5 +1,4 @@
-### R code from vignette source 'simLexis'
-### Encoding: UTF-8
+### R code from vignette source 'simLexis.rnw'
 
 ###################################################
 ### code chunk number 1: simLexis.rnw:23-26
@@ -41,6 +40,7 @@ summary( dmi, timeScales=T )
 ###################################################
 ### code chunk number 5: boxes
 ###################################################
+getOption("SweaveHooks")[["fig"]]()
 boxes( dmi, boxpos = list(x=c(20,20,80,80),
                         y=c(80,20,80,20)),
             scale.R = 1000, show.BE = TRUE )
@@ -173,6 +173,7 @@ pr.rates[,ia, ii ,"All"   ,] <- ci.pred( All.Dead, newdata = dnew )
 ###################################################
 ### code chunk number 16: mort-int
 ###################################################
+getOption("SweaveHooks")[["fig"]]()
 par( mar=c(3,3,1,1), mgp=c(3,1,0)/1.6, las=1 )
 plot( NA, xlim=c(40,82), ylim=c(5,300), bty="n",
       log="y", xlab="Age", ylab="Mortality rate per 1000 PY" )
@@ -279,6 +280,7 @@ nSt[1:10,]
 ###################################################
 ### code chunk number 26: pstate0
 ###################################################
+getOption("SweaveHooks")[["fig"]]()
 pM <- pState( nSt, perm=c(1,2,4,3) )
 head( pM )
 par( mfrow=c(1,2), mar=c(3,3,1,1), mgp=c(3,1,0)/1.6 )
@@ -294,6 +296,7 @@ box()
 ###################################################
 ### code chunk number 27: pstatex
 ###################################################
+getOption("SweaveHooks")[["fig"]]()
 clr <- c("limegreen","orange")
 # expand with a lighter version of the two chosen colors
 clx <- c( clr, rgb( t( col2rgb( clr[2:1] )*2 + rep(255,3) ) / 3, max=255 ) )
@@ -328,6 +331,7 @@ axis( side=4, at=1:99/100, labels=FALSE, tcl=-0.3 )
 ###################################################
 ### code chunk number 28: pstatey
 ###################################################
+getOption("SweaveHooks")[["fig"]]()
 par( mfrow=c(1,2), las=1, mar=c(3,3,4,2), mgp=c(3,1,0)/1.6 )
 # Men
 pM <- pState( nState( subset(simL,sex=="M"),
@@ -366,6 +370,7 @@ axis( side=4, at=1:99/100, labels=FALSE, tcl=-0.3 )
 ###################################################
 ### code chunk number 29: comp-0
 ###################################################
+getOption("SweaveHooks")[["fig"]]()
 PrM  <- pState( nState( subset(simP,sex=="M"),
                         at=seq(0,11,0.2),
                         from=60,
@@ -401,82 +406,3 @@ text( 60.5, 0.05, "F" )
 box( lwd=5, col="white" ) ; box( lwd=2, col="black" )
 
 
-###################################################
-### code chunk number 30: CHANGE1
-###################################################
-source( "../R/simLexis.R", keep.source=TRUE )
-
-
-###################################################
-### code chunk number 31: CHANGE2 (eval = FALSE)
-###################################################
-## simX <- Epi:::simX
-## sim1 <- Epi:::sim1
-## lint <- Epi:::lint
-## get.next <- Epi:::get.next
-## chop.lex <- Epi:::chop.lex
-
-
-###################################################
-### code chunk number 32: simLexis.rnw:972-975
-###################################################
-cbind(
-attr( ini, "time.scales" ),
-attr( ini, "time.since" ) )
-
-
-###################################################
-### code chunk number 33: simLexis.rnw:1000-1001
-###################################################
-simLexis
-
-
-###################################################
-### code chunk number 34: simLexis.rnw:1018-1019
-###################################################
-simX
-
-
-###################################################
-### code chunk number 35: simLexis.rnw:1031-1032
-###################################################
-sim1
-
-
-###################################################
-### code chunk number 36: simLexis.rnw:1044-1045
-###################################################
-lint
-
-
-###################################################
-### code chunk number 37: simLexis.rnw:1055-1056
-###################################################
-get.next
-
-
-###################################################
-### code chunk number 38: simLexis.rnw:1065-1066
-###################################################
-chop.lex
-
-
-###################################################
-### code chunk number 39: simLexis.rnw:1083-1084
-###################################################
-nState
-
-
-###################################################
-### code chunk number 40: simLexis.rnw:1093-1094
-###################################################
-pState
-
-
-###################################################
-### code chunk number 41: simLexis.rnw:1098-1100
-###################################################
-plot.pState
-lines.pState
-
-
